# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main.ui'
#
# Created: Fri Jan 11 23:34:58 2013
#      by: PyQt4 UI code generator 4.9.6
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(1000, 980)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(60, 60))
        MainWindow.setMaximumSize(QtCore.QSize(1000, 16777215))
        MainWindow.setWindowOpacity(1.0)
        MainWindow.setAutoFillBackground(True)
        self.centralwidget = QtGui.QWidget(MainWindow)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMinimumSize(QtCore.QSize(0, 0))
        self.centralwidget.setMaximumSize(QtCore.QSize(1000, 16777215))
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.centralwidget)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.scrollArea = QtGui.QScrollArea(self.centralwidget)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName(_fromUtf8("scrollArea"))
        self.scrollAreaWidgetContents = QtGui.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 986, 927))
        self.scrollAreaWidgetContents.setObjectName(_fromUtf8("scrollAreaWidgetContents"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.tabWidget = QtGui.QTabWidget(self.scrollAreaWidgetContents)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(940, 0))
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.tab = QtGui.QWidget()
        self.tab.setObjectName(_fromUtf8("tab"))
        self.gridLayout = QtGui.QGridLayout(self.tab)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.groupBox_4 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        self.groupBox_4.setMinimumSize(QtCore.QSize(480, 150))
        self.groupBox_4.setFlat(False)
        self.groupBox_4.setCheckable(True)
        self.groupBox_4.setObjectName(_fromUtf8("groupBox_4"))
        self.gridLayout.addWidget(self.groupBox_4, 4, 1, 1, 1)
        self.groupBox = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(460, 230))
        self.groupBox.setAutoFillBackground(False)
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.headerFileTextBrowser = QtGui.QTextBrowser(self.groupBox)
        self.headerFileTextBrowser.setGeometry(QtCore.QRect(10, 30, 441, 31))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headerFileTextBrowser.sizePolicy().hasHeightForWidth())
        self.headerFileTextBrowser.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        font.setItalic(True)
        self.headerFileTextBrowser.setFont(font)
        self.headerFileTextBrowser.setObjectName(_fromUtf8("headerFileTextBrowser"))
        self.label_4 = QtGui.QLabel(self.groupBox)
        self.label_4.setGeometry(QtCore.QRect(10, 70, 81, 21))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.pulseTypeTextBrowser = QtGui.QTextBrowser(self.groupBox)
        self.pulseTypeTextBrowser.setGeometry(QtCore.QRect(90, 70, 361, 21))
        font = QtGui.QFont()
        font.setItalic(True)
        self.pulseTypeTextBrowser.setFont(font)
        self.pulseTypeTextBrowser.setAcceptDrops(True)
        self.pulseTypeTextBrowser.setObjectName(_fromUtf8("pulseTypeTextBrowser"))
        self.lcdNumberNuTx = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberNuTx.setGeometry(QtCore.QRect(160, 100, 64, 23))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lcdNumberNuTx.sizePolicy().hasHeightForWidth())
        self.lcdNumberNuTx.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.lcdNumberNuTx.setFont(font)
        self.lcdNumberNuTx.setWhatsThis(_fromUtf8(""))
        self.lcdNumberNuTx.setAutoFillBackground(False)
        self.lcdNumberNuTx.setStyleSheet(_fromUtf8("#lcdNumberNuTx {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberNuTx:disabled {\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberNuTx.setFrameShadow(QtGui.QFrame.Raised)
        self.lcdNumberNuTx.setLineWidth(1)
        self.lcdNumberNuTx.setMidLineWidth(0)
        self.lcdNumberNuTx.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberNuTx.setProperty("value", 0.0)
        self.lcdNumberNuTx.setObjectName(_fromUtf8("lcdNumberNuTx"))
        self.lcdNumberTuneuF = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberTuneuF.setGeometry(QtCore.QRect(370, 100, 64, 23))
        self.lcdNumberTuneuF.setStyleSheet(_fromUtf8("#lcdNumberTuneuF {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTuneuF:disabled {\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberTuneuF.setLineWidth(1)
        self.lcdNumberTuneuF.setMidLineWidth(0)
        self.lcdNumberTuneuF.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberTuneuF.setObjectName(_fromUtf8("lcdNumberTuneuF"))
        self.lcdNumberTauPulse1 = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberTauPulse1.setGeometry(QtCore.QRect(160, 130, 64, 23))
        self.lcdNumberTauPulse1.setStyleSheet(_fromUtf8("#lcdNumberTauPulse1 {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauPulse1:disabled {\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberTauPulse1.setFrameShadow(QtGui.QFrame.Raised)
        self.lcdNumberTauPulse1.setLineWidth(1)
        self.lcdNumberTauPulse1.setMidLineWidth(0)
        self.lcdNumberTauPulse1.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberTauPulse1.setObjectName(_fromUtf8("lcdNumberTauPulse1"))
        self.label_6 = QtGui.QLabel(self.groupBox)
        self.label_6.setGeometry(QtCore.QRect(10, 100, 91, 21))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.label_7 = QtGui.QLabel(self.groupBox)
        self.label_7.setGeometry(QtCore.QRect(10, 130, 141, 21))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.label_13 = QtGui.QLabel(self.groupBox)
        self.label_13.setGeometry(QtCore.QRect(260, 160, 91, 21))
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.lcdNumberTauPulse2 = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberTauPulse2.setGeometry(QtCore.QRect(160, 160, 64, 23))
        self.lcdNumberTauPulse2.setStyleSheet(_fromUtf8("#lcdNumberTauPulse2 {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauPulse2:disabled{\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberTauPulse2.setLineWidth(1)
        self.lcdNumberTauPulse2.setMidLineWidth(0)
        self.lcdNumberTauPulse2.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberTauPulse2.setObjectName(_fromUtf8("lcdNumberTauPulse2"))
        self.label_14 = QtGui.QLabel(self.groupBox)
        self.label_14.setGeometry(QtCore.QRect(260, 100, 111, 21))
        self.label_14.setObjectName(_fromUtf8("label_14"))
        self.label_15 = QtGui.QLabel(self.groupBox)
        self.label_15.setGeometry(QtCore.QRect(260, 130, 111, 21))
        self.label_15.setObjectName(_fromUtf8("label_15"))
        self.lcdNumberSampFreq = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberSampFreq.setEnabled(True)
        self.lcdNumberSampFreq.setGeometry(QtCore.QRect(370, 130, 64, 23))
        self.lcdNumberSampFreq.setStyleSheet(_fromUtf8("#lcdNumberSampFreq {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberSampFreq:disabled{\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberSampFreq.setLineWidth(1)
        self.lcdNumberSampFreq.setMidLineWidth(0)
        self.lcdNumberSampFreq.setDigitCount(5)
        self.lcdNumberSampFreq.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberSampFreq.setObjectName(_fromUtf8("lcdNumberSampFreq"))
        self.lcdNumberTauDelay = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberTauDelay.setEnabled(True)
        self.lcdNumberTauDelay.setGeometry(QtCore.QRect(370, 160, 64, 23))
        self.lcdNumberTauDelay.setStyleSheet(_fromUtf8("#lcdNumberTauDelay {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberTauDelay:disabled {\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberTauDelay.setLineWidth(1)
        self.lcdNumberTauDelay.setMidLineWidth(0)
        self.lcdNumberTauDelay.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberTauDelay.setObjectName(_fromUtf8("lcdNumberTauDelay"))
        self.label_16 = QtGui.QLabel(self.groupBox)
        self.label_16.setGeometry(QtCore.QRect(10, 160, 131, 21))
        self.label_16.setObjectName(_fromUtf8("label_16"))
        self.lcdNumberNQ = QtGui.QLCDNumber(self.groupBox)
        self.lcdNumberNQ.setGeometry(QtCore.QRect(160, 190, 64, 23))
        self.lcdNumberNQ.setStyleSheet(_fromUtf8("#lcdNumberNQ {\n"
"color: green;\n"
"background: black;\n"
"}\n"
"\n"
"#lcdNumberNQ:disabled{\n"
"color: grey;\n"
"background: black;\n"
"}"))
        self.lcdNumberNQ.setSegmentStyle(QtGui.QLCDNumber.Flat)
        self.lcdNumberNQ.setObjectName(_fromUtf8("lcdNumberNQ"))
        self.label_9 = QtGui.QLabel(self.groupBox)
        self.label_9.setGeometry(QtCore.QRect(10, 190, 141, 21))
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.gridLayout.addWidget(self.groupBox, 4, 0, 1, 1)
        self.groupBox_10 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_10.sizePolicy().hasHeightForWidth())
        self.groupBox_10.setSizePolicy(sizePolicy)
        self.groupBox_10.setMinimumSize(QtCore.QSize(460, 160))
        self.groupBox_10.setObjectName(_fromUtf8("groupBox_10"))
        self.stacksLineEdit = QtGui.QLineEdit(self.groupBox_10)
        self.stacksLineEdit.setGeometry(QtCore.QRect(110, 30, 91, 21))
        self.stacksLineEdit.setToolTip(_fromUtf8("<html><head/><body><p>Set the stacks that you would like processed.</p><p>This must be a valid set of numpy array indices. Remember that Python uses non end-inclusive indexing. </p><p>So things like [1:24] will include stacks 1-23</p><p>Furthermore [1:8,12:24] will include stacks 1-7 and 12:23. Any list of valid indices will be accepted, but they must be comma seperated. </p></body></html>"))
        self.stacksLineEdit.setObjectName(_fromUtf8("stacksLineEdit"))
        self.label = QtGui.QLabel(self.groupBox_10)
        self.label.setGeometry(QtCore.QRect(10, 30, 51, 20))
        self.label.setToolTip(_fromUtf8(""))
        self.label.setStatusTip(_fromUtf8(""))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_23 = QtGui.QLabel(self.groupBox_10)
        self.label_23.setGeometry(QtCore.QRect(10, 65, 101, 16))
        self.label_23.setObjectName(_fromUtf8("label_23"))
        self.dataChanLineEdit = QtGui.QLineEdit(self.groupBox_10)
        self.dataChanLineEdit.setGeometry(QtCore.QRect(110, 60, 91, 21))
        self.dataChanLineEdit.setObjectName(_fromUtf8("dataChanLineEdit"))
        self.label_24 = QtGui.QLabel(self.groupBox_10)
        self.label_24.setGeometry(QtCore.QRect(220, 36, 101, 16))
        self.label_24.setObjectName(_fromUtf8("label_24"))
        self.DeadTimeSpinBox = QtGui.QDoubleSpinBox(self.groupBox_10)
        self.DeadTimeSpinBox.setGeometry(QtCore.QRect(360, 30, 91, 25))
        self.DeadTimeSpinBox.setMinimum(5.0)
        self.DeadTimeSpinBox.setSingleStep(0.5)
        self.DeadTimeSpinBox.setProperty("value", 5.0)
        self.DeadTimeSpinBox.setObjectName(_fromUtf8("DeadTimeSpinBox"))
        self.label_28 = QtGui.QLabel(self.groupBox_10)
        self.label_28.setGeometry(QtCore.QRect(220, 64, 131, 16))
        self.label_28.setObjectName(_fromUtf8("label_28"))
        self.refChanLineEdit = QtGui.QLineEdit(self.groupBox_10)
        self.refChanLineEdit.setGeometry(QtCore.QRect(360, 60, 91, 21))
        self.refChanLineEdit.setObjectName(_fromUtf8("refChanLineEdit"))
        self.label_30 = QtGui.QLabel(self.groupBox_10)
        self.label_30.setGeometry(QtCore.QRect(12, 96, 91, 16))
        self.label_30.setObjectName(_fromUtf8("label_30"))
        self.CentralVSpinBox = QtGui.QDoubleSpinBox(self.groupBox_10)
        self.CentralVSpinBox.setGeometry(QtCore.QRect(110, 90, 91, 25))
        self.CentralVSpinBox.setMinimum(100.0)
        self.CentralVSpinBox.setMaximum(5000.99)
        self.CentralVSpinBox.setSingleStep(1.0)
        self.CentralVSpinBox.setObjectName(_fromUtf8("CentralVSpinBox"))
        self.label_29 = QtGui.QLabel(self.groupBox_10)
        self.label_29.setGeometry(QtCore.QRect(220, 95, 111, 16))
        self.label_29.setObjectName(_fromUtf8("label_29"))
        self.FIDProcComboBox = QtGui.QComboBox(self.groupBox_10)
        self.FIDProcComboBox.setGeometry(QtCore.QRect(360, 90, 91, 25))
        self.FIDProcComboBox.setObjectName(_fromUtf8("FIDProcComboBox"))
        self.fullWorkflowPushButton = QtGui.QPushButton(self.groupBox_10)
        self.fullWorkflowPushButton.setGeometry(QtCore.QRect(280, 130, 131, 31))
        self.fullWorkflowPushButton.setAutoFillBackground(False)
        self.fullWorkflowPushButton.setStyleSheet(_fromUtf8("#fullWorkflowPushButton {\n"
"background: green;\n"
"}"))
        self.fullWorkflowPushButton.setAutoDefault(False)
        self.fullWorkflowPushButton.setDefault(False)
        self.fullWorkflowPushButton.setFlat(False)
        self.fullWorkflowPushButton.setObjectName(_fromUtf8("fullWorkflowPushButton"))
        self.loadDataPushButton = QtGui.QPushButton(self.groupBox_10)
        self.loadDataPushButton.setGeometry(QtCore.QRect(90, 130, 91, 31))
        self.loadDataPushButton.setObjectName(_fromUtf8("loadDataPushButton"))
        self.gridLayout.addWidget(self.groupBox_10, 5, 0, 1, 1)
        self.groupBox_9 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_9.sizePolicy().hasHeightForWidth())
        self.groupBox_9.setSizePolicy(sizePolicy)
        self.groupBox_9.setMinimumSize(QtCore.QSize(480, 100))
        self.groupBox_9.setCheckable(True)
        self.groupBox_9.setObjectName(_fromUtf8("groupBox_9"))
        self.checkBox = QtGui.QCheckBox(self.groupBox_9)
        self.checkBox.setGeometry(QtCore.QRect(30, 30, 171, 20))
        self.checkBox.setObjectName(_fromUtf8("checkBox"))
        self.comboBox_2 = QtGui.QComboBox(self.groupBox_9)
        self.comboBox_2.setGeometry(QtCore.QRect(130, 50, 78, 25))
        self.comboBox_2.setObjectName(_fromUtf8("comboBox_2"))
        self.label_5 = QtGui.QLabel(self.groupBox_9)
        self.label_5.setGeometry(QtCore.QRect(40, 60, 71, 16))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.doubleSpinBox = QtGui.QDoubleSpinBox(self.groupBox_9)
        self.doubleSpinBox.setGeometry(QtCore.QRect(390, 20, 62, 25))
        self.doubleSpinBox.setObjectName(_fromUtf8("doubleSpinBox"))
        self.label_8 = QtGui.QLabel(self.groupBox_9)
        self.label_8.setGeometry(QtCore.QRect(220, 20, 161, 20))
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.gridLayout.addWidget(self.groupBox_9, 5, 1, 1, 1)
        self.groupBox_7 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_7.sizePolicy().hasHeightForWidth())
        self.groupBox_7.setSizePolicy(sizePolicy)
        self.groupBox_7.setMinimumSize(QtCore.QSize(480, 100))
        self.groupBox_7.setCheckable(True)
        self.groupBox_7.setObjectName(_fromUtf8("groupBox_7"))
        self.comboBox = QtGui.QComboBox(self.groupBox_7)
        self.comboBox.setGeometry(QtCore.QRect(40, 30, 141, 22))
        self.comboBox.setMouseTracking(True)
        self.comboBox.setToolTip(_fromUtf8(""))
        self.comboBox.setStatusTip(_fromUtf8(""))
        self.comboBox.setWhatsThis(_fromUtf8(""))
        self.comboBox.setObjectName(_fromUtf8("comboBox"))
        self.comboBox.addItem(_fromUtf8(""))
        self.comboBox.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.groupBox_7, 2, 1, 1, 1)
        self.label_2 = QtGui.QLabel(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(20)
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 0, 1, 1, 1)
        self.groupBox_8 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_8.sizePolicy().hasHeightForWidth())
        self.groupBox_8.setSizePolicy(sizePolicy)
        self.groupBox_8.setMinimumSize(QtCore.QSize(480, 150))
        self.groupBox_8.setCheckable(True)
        self.groupBox_8.setObjectName(_fromUtf8("groupBox_8"))
        self.label_3 = QtGui.QLabel(self.groupBox_8)
        self.label_3.setGeometry(QtCore.QRect(30, 60, 111, 16))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.spinBox = QtGui.QSpinBox(self.groupBox_8)
        self.spinBox.setGeometry(QtCore.QRect(140, 60, 101, 25))
        self.spinBox.setMaximum(1000)
        self.spinBox.setProperty("value", 300)
        self.spinBox.setObjectName(_fromUtf8("spinBox"))
        self.gridLayout.addWidget(self.groupBox_8, 3, 1, 1, 1)
        self.groupBox_5 = QtGui.QGroupBox(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setMinimumSize(QtCore.QSize(480, 150))
        self.groupBox_5.setCheckable(True)
        self.groupBox_5.setObjectName(_fromUtf8("groupBox_5"))
        self.gridLayout.addWidget(self.groupBox_5, 1, 1, 1, 1)
        self.mplwidget = MyDynamicMplCanvas(self.tab)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mplwidget.sizePolicy().hasHeightForWidth())
        self.mplwidget.setSizePolicy(sizePolicy)
        self.mplwidget.setMinimumSize(QtCore.QSize(460, 460))
        self.mplwidget.setObjectName(_fromUtf8("mplwidget"))
        self.gridLayout.addWidget(self.mplwidget, 0, 0, 4, 1)
        self.tabWidget.addTab(self.tab, _fromUtf8(""))
        self.tab_3 = QtGui.QWidget()
        self.tab_3.setObjectName(_fromUtf8("tab_3"))
        self.treeWidget = QtGui.QTreeWidget(self.tab_3)
        self.treeWidget.setGeometry(QtCore.QRect(70, 50, 256, 192))
        self.treeWidget.setObjectName(_fromUtf8("treeWidget"))
        self.treeWidget.headerItem().setText(0, _fromUtf8("1"))
        self.toolBox = QtGui.QToolBox(self.tab_3)
        self.toolBox.setGeometry(QtCore.QRect(320, 460, 79, 137))
        self.toolBox.setObjectName(_fromUtf8("toolBox"))
        self.page = QtGui.QWidget()
        self.page.setGeometry(QtCore.QRect(0, 0, 94, 24))
        self.page.setObjectName(_fromUtf8("page"))
        self.toolBox.addItem(self.page, _fromUtf8(""))
        self.page_2 = QtGui.QWidget()
        self.page_2.setGeometry(QtCore.QRect(0, 0, 94, 24))
        self.page_2.setObjectName(_fromUtf8("page_2"))
        self.toolBox.addItem(self.page_2, _fromUtf8(""))
        self.dateEdit = QtGui.QDateEdit(self.tab_3)
        self.dateEdit.setGeometry(QtCore.QRect(400, 280, 110, 25))
        self.dateEdit.setObjectName(_fromUtf8("dateEdit"))
        self.tabWidget.addTab(self.tab_3, _fromUtf8(""))
        self.tab_2 = QtGui.QWidget()
        self.tab_2.setObjectName(_fromUtf8("tab_2"))
        self.dateEdit_2 = QtGui.QDateEdit(self.tab_2)
        self.dateEdit_2.setGeometry(QtCore.QRect(50, 100, 110, 25))
        self.dateEdit_2.setObjectName(_fromUtf8("dateEdit_2"))
        self.tabWidget.addTab(self.tab_2, _fromUtf8(""))
        self.tab_6 = QtGui.QWidget()
        self.tab_6.setObjectName(_fromUtf8("tab_6"))
        self.tabWidget.addTab(self.tab_6, _fromUtf8(""))
        self.tab_4 = QtGui.QWidget()
        self.tab_4.setObjectName(_fromUtf8("tab_4"))
        self.invertButton = QtGui.QPushButton(self.tab_4)
        self.invertButton.setGeometry(QtCore.QRect(290, 140, 311, 141))
        self.invertButton.setStyleSheet(_fromUtf8("#invertButton {\n"
"font-size:29pt;\n"
"font-weight: bold;\n"
"color: white;\n"
"background: red;\n"
"}"))
        self.invertButton.setObjectName(_fromUtf8("invertButton"))
        self.tabWidget.addTab(self.tab_4, _fromUtf8(""))
        self.tab_5 = QtGui.QWidget()
        self.tab_5.setObjectName(_fromUtf8("tab_5"))
        self.tabWidget.addTab(self.tab_5, _fromUtf8(""))
        self.horizontalLayout_2.addWidget(self.tabWidget)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.horizontalLayout.addWidget(self.scrollArea)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1000, 20))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menuAbout = QtGui.QMenu(self.menubar)
        self.menuAbout.setObjectName(_fromUtf8("menuAbout"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.actionClose = QtGui.QAction(MainWindow)
        self.actionClose.setObjectName(_fromUtf8("actionClose"))
        self.actionAboutBrewCentral = QtGui.QAction(MainWindow)
        self.actionAboutBrewCentral.setObjectName(_fromUtf8("actionAboutBrewCentral"))
        self.actionNothing = QtGui.QAction(MainWindow)
        self.actionNothing.setObjectName(_fromUtf8("actionNothing"))
        self.actionTemperature = QtGui.QAction(MainWindow)
        self.actionTemperature.setObjectName(_fromUtf8("actionTemperature"))
        self.actionOpen_GMR = QtGui.QAction(MainWindow)
        self.actionOpen_GMR.setCheckable(False)
        self.actionOpen_GMR.setObjectName(_fromUtf8("actionOpen_GMR"))
        self.actionProcess = QtGui.QAction(MainWindow)
        self.actionProcess.setCheckable(True)
        self.actionProcess.setObjectName(_fromUtf8("actionProcess"))
        self.actionOpen_Preprocessed_dataset = QtGui.QAction(MainWindow)
        self.actionOpen_Preprocessed_dataset.setEnabled(False)
        self.actionOpen_Preprocessed_dataset.setObjectName(_fromUtf8("actionOpen_Preprocessed_dataset"))
        self.actionOpen_VC_Preprocessed_dataset = QtGui.QAction(MainWindow)
        self.actionOpen_VC_Preprocessed_dataset.setEnabled(False)
        self.actionOpen_VC_Preprocessed_dataset.setObjectName(_fromUtf8("actionOpen_VC_Preprocessed_dataset"))
        self.actionSave_Preprocesssed_Dataset = QtGui.QAction(MainWindow)
        self.actionSave_Preprocesssed_Dataset.setEnabled(False)
        self.actionSave_Preprocesssed_Dataset.setObjectName(_fromUtf8("actionSave_Preprocesssed_Dataset"))
        self.menuFile.addAction(self.actionOpen_GMR)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionOpen_Preprocessed_dataset)
        self.menuFile.addAction(self.actionOpen_VC_Preprocessed_dataset)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave_Preprocesssed_Dataset)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionClose)
        self.menuAbout.addAction(self.actionAboutBrewCentral)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.toolBox.setCurrentIndex(0)
        QtCore.QObject.connect(self.actionClose, QtCore.SIGNAL(_fromUtf8("activated()")), MainWindow.close)
        QtCore.QObject.connect(self.actionAboutBrewCentral, QtCore.SIGNAL(_fromUtf8("activated()")), MainWindow.show)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "Avko - sNMR Workbench", None))
        self.groupBox_4.setTitle(_translate("MainWindow", "Adaptive Noise Suppresion", None))
        self.groupBox.setTitle(_translate("MainWindow", "Header file info", None))
        self.headerFileTextBrowser.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:8pt; font-weight:400; font-style:italic;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'DejaVu Serif\'; font-size:9pt;\">Load supported RAW Dataset header from file menu</span></p></body></html>", None))
        self.label_4.setText(_translate("MainWindow", "Pulse Type", None))
        self.pulseTypeTextBrowser.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:italic;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'DejaVu Serif\'; font-size:10pt;\"><br /></p></body></html>", None))
        self.label_6.setText(_translate("MainWindow", "ν Tx  [Hz]", None))
        self.label_7.setText(_translate("MainWindow", "τ Pulse 1 [ms]", None))
        self.label_13.setText(_translate("MainWindow", "τ Delay [ms]", None))
        self.label_14.setText(_translate("MainWindow", "Tx tuning [μF]", None))
        self.label_15.setText(_translate("MainWindow", "ν Sampling [Hz]", None))
        self.label_16.setText(_translate("MainWindow", "τ Pulse 2 [ms]", None))
        self.label_9.setText(_translate("MainWindow", "Num. pulse moments", None))
        self.groupBox_10.setTitle(_translate("MainWindow", "Input parameters", None))
        self.label.setText(_translate("MainWindow", "Stacks", None))
        self.label_23.setText(_translate("MainWindow", "Data Channels", None))
        self.label_24.setText(_translate("MainWindow", "Dead time [ms]", None))
        self.label_28.setText(_translate("MainWindow", "Reference Channels", None))
        self.label_30.setText(_translate("MainWindow", "Central ν Hz", None))
        self.CentralVSpinBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>In case of off-resonant transmitter pulse, you can set the central frequency that will be used for all processing. This has the biggest impact on the band-pass filter, and the frequencies used in inversion. </p></body></html>", None))
        self.label_29.setText(_translate("MainWindow", "Process FID #", None))
        self.FIDProcComboBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>For T1 or CPMG pulses, which pulse(s) would you like to process. Note that for very short delay T1 pulses, the first pulse may be disabled. </p></body></html>", None))
        self.fullWorkflowPushButton.setText(_translate("MainWindow", "Full Workflow", None))
        self.loadDataPushButton.setText(_translate("MainWindow", "Load Data", None))
        self.groupBox_9.setTitle(_translate("MainWindow", "SmartStack^TM", None))
        self.checkBox.setText(_translate("MainWindow", "Correct phase jitter", None))
        self.label_5.setText(_translate("MainWindow", "Outlier test", None))
        self.label_8.setText(_translate("MainWindow", "Instrument phase delay", None))
        self.groupBox_7.setTitle(_translate("MainWindow", "Band-Pass Filter", None))
        self.comboBox.setAccessibleDescription(_translate("MainWindow", "Hello", None))
        self.comboBox.setItemText(0, _translate("MainWindow", "Butterworth", None))
        self.comboBox.setItemText(1, _translate("MainWindow", "Chebychev Type II", None))
        self.label_2.setText(_translate("MainWindow", "         Preprocessing Workflow", None))
        self.groupBox_8.setTitle(_translate("MainWindow", "Downsample and truncate", None))
        self.label_3.setText(_translate("MainWindow", "Truncate [ms]", None))
        self.groupBox_5.setTitle(_translate("MainWindow", "Despike Filter", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Preprocess RAW", None))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page), _translate("MainWindow", "Page 1", None))
        self.toolBox.setItemText(self.toolBox.indexOf(self.page_2), _translate("MainWindow", "Page 2", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Data QC", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Model Parameters", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), _translate("MainWindow", "Forward modelling", None))
        self.invertButton.setText(_translate("MainWindow", "Invert", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "Inversion", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("MainWindow", "Analysis", None))
        self.menuFile.setTitle(_translate("MainWindow", "&File", None))
        self.menuAbout.setTitle(_translate("MainWindow", "About", None))
        self.actionClose.setText(_translate("MainWindow", "&Close", None))
        self.actionAboutBrewCentral.setText(_translate("MainWindow", "Brew Central", None))
        self.actionNothing.setText(_translate("MainWindow", "Nothing", None))
        self.actionTemperature.setText(_translate("MainWindow", "Temperature", None))
        self.actionOpen_GMR.setText(_translate("MainWindow", "Open GMR RAW header", None))
        self.actionOpen_GMR.setIconText(_translate("MainWindow", "Open GMR RAW dataset(s)", None))
        self.actionProcess.setText(_translate("MainWindow", "Process", None))
        self.actionOpen_Preprocessed_dataset.setText(_translate("MainWindow", "Open Avko Preprocessed dataset", None))
        self.actionOpen_VC_Preprocessed_dataset.setText(_translate("MainWindow", "Open VC Preprocessed dataset", None))
        self.actionSave_Preprocesssed_Dataset.setText(_translate("MainWindow", "Save Preprocesssed Dataset", None))

from mydynamicmplcanvas import MyDynamicMplCanvas
